OC.L10N.register(
    "lib",
    {
    "Help" : "Hëllef",
    "Personal" : "Perséinlech",
    "Users" : "Benotzer",
    "Admin" : "Admin",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongülteg d'Bild",
    "today" : "haut",
    "yesterday" : "gëschter",
    "last month" : "Läschte Mount",
    "last year" : "Läscht Joer",
    "seconds ago" : "Sekonnen hir",
    "web services under your control" : "Web-Servicer ënnert denger Kontroll",
    "Authentication error" : "Authentifikatioun's Fehler",
    "%s shared »%s« with you" : "Den/D' %s huet »%s« mat dir gedeelt"
},
"nplurals=2; plural=(n != 1);");
